<template>
    <el-dialog
        :visible.sync="citySaleDetailVisible"
        :close-on-click-modal="false"
        width="60%"
    >
        <div class="basic_search" style="margin-right: 10px">
            <el-button style="margin-left: 10px;" type="primary" icon="el-icon-download" @click="exportToExcel">导出</el-button>
        </div>
        <div class="table_content">
            <el-table
                v-loading="listLoading"
                :key="tableKey"
                :data="citySaleDetailData"
                border
                fit
                highlight-current-row
                style="width: 100%;"
            >
                <el-table-column label="序号" type="index" align="center" width="60"/>
                <el-table-column label="县区" prop="name" align="center">
                </el-table-column>
                <el-table-column label="爆竹类（箱）" prop="num_爆竹类" align="center">
                </el-table-column>
                <el-table-column label="喷花类（箱）" prop="num_喷花类" align="center">
                </el-table-column>
                <el-table-column label="旋转类（箱）" prop="num_旋转类" align="center">
                </el-table-column>
                <el-table-column label="吐珠类（箱）" prop="num_吐珠类" align="center">
                </el-table-column>
                <el-table-column label="玩具类（箱）" prop="num_玩具类" align="center">
                </el-table-column>
                <el-table-column label="组合烟花类（箱）" prop="num_组合烟花类" align="center">
                </el-table-column>
                <el-table-column label="合计（箱）" prop="totalcol" align="center">
                </el-table-column>
                <el-table-column label="总人数" prop="personnum" align="center">
                </el-table-column>
            </el-table>
            <br>
            <el-pagination
                v-show="recordTotal>0"
                :current-page="currentPage"
                :page-sizes="[10, 20, 30, 50]"
                :page-size="pageSize"
                :total="recordTotal"
                layout="total, sizes, prev, pager, next, jumper"
                background
                style="float:right;"
                @size-change="handleSizeChange"
                @current-change="handleCurrentChange"
            />
            <br>
        </div>
    </el-dialog>
</template>

<script>
import {districtTypeSale, districtTypeSaleExport} from "@/api/productPurchaseSearch";
import {computePageCount} from "../../../utils";

export default {
    name: "index",
    data(){
        return{
            tableKey:'',
            listLoading:false,
            pageSize: 20,
            recordTotal: 0,
            currentPage: 1,
            pageTotal: 0,
            citySaleDetailData:[],
            citySaleDetailVisible:false,
            listQuery: {
                pageSize:20,
                pageIndex:1,
                filter: {
                    starttime: '',
                    endtime: '',
                    enterprisename: '',
                    safetysupervision: '',
                    city:'',
                },
            },
        }
    },
    created() {

    },
    methods:{
        showCitySaleDetail(startTime,endTime,enterprisename,safetysupervision,city){
            this.listQuery.filter.starttime = startTime
            this.listQuery.filter.endtime = endTime
            this.listQuery.filter.enterprisename = enterprisename
            this.listQuery.filter.safetysupervision = safetysupervision
            this.listQuery.filter.city = city
            this.listQuery.pageIndex = 1;
            this.listQuery.pageSize = 20;
            this.citySaleDetailVisible = true
            this.getCitySaleDetailList()
        },
         async getCitySaleDetailList(){
            this.listLoading = true
            let res = await districtTypeSale(this.listQuery)
            if(res.data.code === "200"){
                this.recordTotal = res.data.result.total
                this.pageSize = res.data.result.size
                this.pageTotal = computePageCount(res.data.result.total, res.data.result.size)
                this.currentPage = res.data.result.current
                this.citySaleDetailData = res.data.result.records
            }else{
                this.$message({
                    type:'warning',
                    message:res.data.message
                })
            }
            this.listLoading = false
        },
        handleSizeChange(val) {
            this.listQuery.pageSize = val
            this.getCitySaleDetailList()
        },
        handleCurrentChange(val) {
            this.listQuery.pageIndex = val
            this.getCitySaleDetailList()
        },
        async exportToExcel(){
            let res = await districtTypeSaleExport(this.listQuery)
            if(res.data.code === '200'){
                if(res.data.result === null ||res.data.result === [] || res.data.result.length === 0){
                    debugger
                    this.$message({
                        type:'warning',
                        message:'无数据可导出'
                    })
                }else{
                    let allData = res.data.result
                    import('@/vendor/Export2Excel').then((excel) => {
                        const tHeader = [
                            '地区',
                            '爆竹类（箱）',
                            '喷花类（箱）',
                            '旋转类（箱）',
                            '吐珠类（箱）',
                            '玩具类（箱）',
                            '组合烟花类（箱）',
                            '合计（箱）',
                            '总人数',
                        ]
                        const filterVal = [
                            'name',
                            'num_爆竹类',
                            'num_喷花类',
                            'num_旋转类',
                            'num_吐珠类',
                            'num_玩具类',
                            'num_组合烟花类',
                            'totalcol',
                            'personnum'
                        ]
                        const data = this.formatJson(filterVal, allData)
                        excel.export_json_to_excel({
                            header: tHeader,
                            data,
                            filename: this.listQuery.filter.city+'分类销售统计'
                        })
                    })
                }

            }else{
                this.$message({
                    message:res.data.message,
                    type:'warning'
                })
            }
        },

        formatJson(filterVal, jsonData) {
            return jsonData.map(v => filterVal.map(j => v[j]))
        },
    }
}
</script>

<style scoped>

</style>
